==> igniteui-react-charts-16.6.8.tgz: package/ES2015/FinancialPriceBucketCalculator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { FinancialBucketCalculator } from "./FinancialBucketCalculator";
import { markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class FinancialPriceBucketCalculator extends FinancialBucketCalculator {
    constructor(a) {
        super(a);
    }
    getBucket(a) {
        let b = a * this.b;
        let c = Math.min(b + this.b - 1, this.a.bw.bz.count - 1);
        if (b <= c && b >= 0 && c >= 0) {
            let d = this.a.bw.mv.item(b);
            let e = Number.NEGATIVE_INFINITY;
            let f = Number.POSITIVE_INFINITY;
            let g = this.a.bw.mp.item(c);
            for (let h = b; h <= c; ++h) {
                e = Math.max(e, this.a.bw.mr.item(h));
                f = Math.min(f, this.a.bw.mt.item(h));
            }
            f = Math.min(d, f);
            e = Math.max(g, e);
            return [0.5 * (b + c), d, e, f, g];
        }
        return [NaN, NaN, NaN, NaN, NaN];
    }
}
FinancialPriceBucketCalculator.$t = markType(FinancialPriceBucketCalculator, 'FinancialPriceBucketCalculator', FinancialBucketCalculator.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/FinancialPriceBucketCalculator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { FinancialBucketCalculator } from "./FinancialBucketCalculator";
import { markType } from "igniteui-react-core/ES2015/type";
/**
 * @hidden
 */
export class FinancialPriceBucketCalculator extends FinancialBucketCalculator {
    constructor(a) {
        super(a);
    }
    getBucket(a) {
        let b = a * this.b;
        let c = Math.min(b + this.b - 1, this.a.bw.bz.count - 1);
        if (b <= c && b >= 0 && c >= 0) {
            let d = this.a.bw.m2.item(b);
            let e = Number.NEGATIVE_INFINITY;
            let f = Number.POSITIVE_INFINITY;
            let g = this.a.bw.mw.item(c);
            for (let h = b; h <= c; ++h) {
                e = Math.max(e, this.a.bw.my.item(h));
                f = Math.min(f, this.a.bw.m0.item(h));
            }
            f = Math.min(d, f);
            e = Math.max(g, e);
            return [0.5 * (b + c), d, e, f, g];
        }
        return [NaN, NaN, NaN, NaN, NaN];
    }
}
FinancialPriceBucketCalculator.$t = markType(FinancialPriceBucketCalculator, 'FinancialPriceBucketCalculator', FinancialBucketCalculator.$);
